@@ -382,7 +382,7 @@ class QueryOperator(object):
                     }
 
         """
-        cg_id = constants.DCC_ID_MAPPINGS[name.strip()]
+        cg_id = int(constants.DCC_ID_MAPPINGS[name.strip()])
         platform = "windows" if sys.platform.startswith("win") else "linux"
         data = {'cgId': cg_id, 'osName': platform}
         return self._connect.post(self._connect.url.querySoftwareDetail, data)
