@@ -272,7 +272,7 @@ class RayvisionCheck(object):
         version = task_data["software_config"]["cg_version"]
         cg_name = task_data["software_config"]["cg_name"]
         cg_id = task_data["task_info"]["cg_id"]
-        plugin_name_list = self.api.query.supported_plugin(CG_SETTING[cg_id].lower())["cgVersion"]
+        plugin_name_list = self.api.query.supported_plugin(CG_SETTING[str(cg_id)].lower())["cgVersion"]
         cg_id = None
         all_version = []
 
@@ -289,7 +289,7 @@ class RayvisionCheck(object):
     def set_custom_hardware(self, custom_hardware, task_info, task_path):
         """Check whether the hardware configuration information exists and whether it meets the requirements."""
         hardware_config_list = self.api.user.get_hardware_config()
-        platform = task_info['task_info']['platform']
+        platform = task_info['task_info'].get('platform', self.api.platform)
         cg_id = task_info['task_info']['cg_id']
         plugins = task_info['software_config']['plugins']
         check_keys = ['model', 'ram', 'gpuNum']
